==> rktSNS_1.070131.tgz: rktSNS/webapp/modules/private/show/calendar.php <==
<?php
/* ========================================================================
 - [modules/private/show/calendar.php]
 -      カレンダー
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2006/07/10] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once LIB_DIR.'rkt_pager.php';
require_once LIB_DIR.'rkt_calendar.php';
require_once WEBAPP_LIB_DIR.'sql_query.php';
require_once WEBAPP_LIB_DIR.'wap_private.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends WAP_private
{
    /**
     * 表示対象年月日
     * @var string
     */
    var $date = '';

    /**
     * カレンダーオブジェクト
     * @var object
     */
    var $objcal = null;

    /**
     * スケジュール格納用
     * @var array
     */
    var $schedules = array();

    /**
     * 誕生日格納用
     * @var array
     */
    var $birthdays = array();

    /**
     * イベント格納用
     * @var array
     */
    var $events = array();

    /**
     * 日付の参照範囲
     * @var array
     */
    var $limitday = array();

    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    function execute()
    {
        RKT_auth::Authenticate(array(WAP_ACC_ADMIN,WAP_ACC_MEMBER));

        $this->setTemplateFile('private/show/calendar.tpl');

        /* 表示対象日付 */
        $this->setSafety('date', '_REQUEST', 'string');

        /* カレンダーオブジェクトの生成 */
        $this->objcal = new RKT_calendar($this->date);
        
        $this->set_calendar();
        $this->set_schedule();
        $this->set_birthday(0);
        $this->set_birthday(1);
        $this->Assign('birthdays', $this->birthdays);
        
        $this->set_event();
    }

    /**
     * カレンダーの設定
     *
     * @access private
     */
    function set_calendar()
    {
        $id2yobi = array(    // idから曜日に変換
            RKT_SUN => 'sun',
            RKT_MON => 'mon',
            RKT_TUE => 'tue',
            RKT_WED => 'wed',
            RKT_THU => 'thu',
            RKT_FRI => 'fri',
            RKT_SAT => 'sat'
        );

        $id2style = array(    // idからcssクラス名に変換
            RKT_WEEKDAY => 'calendar',
            RKT_HOLIDAY => 'holiday',
            RKT_SATURDAY =>'saturday',
            RKT_TODAY =>   'today'
        );
        $cals   = $this->objcal->getCalendar();
        $infos  = $this->objcal->getInformation();
        $dates  = $this->objcal->getDates();
        $last   = $this->objcal->getLastday();

        $weeks = array();
        $yobi = '';
        $style = '';

        $calendars = array();
        foreach ($cals as $weekly=>$weeks){
            $cal[$weekly] = array();
            foreach ($weeks as $week=>$day){
                $style = $id2style[$infos[$weekly][$week]];
                if (!empty($this->weeks[$weekly][$week]) && !empty($day)){
                    $this->schedule[$day] = $this->weeks[$weekly][$week];
                }
        
                $calendars[$weekly]['week'][$week] = array('day'=>$day,'style'=>$style);                
            }
        } // foreach ($cals as $weekly=>$weeks)
        $this->month = sprintf('%04d-%02d',$dates[RKT_YEAR],$dates[RKT_MONTH]);

        $this->limitday['start'] =  sprintf('%04d-%02d-01',$dates[RKT_YEAR],$dates[RKT_MONTH]);
        $this->limitday['last']  =  sprintf('%04d-%02d-%d',$dates[RKT_YEAR],$dates[RKT_MONTH],$last);
        $this->limitday['month'] =  sprintf('%02d',$dates[RKT_MONTH]);

        $this->Assign('calendars', $calendars);
        $this->Assign('date', $dates);
        $this->Assign('month', $dates[RKT_MONTH]);
    }

    /**
     * スケジュールリストの設定
     *
     * @access private
     * @return void
     **/
    function set_schedule()
    {
        $sql = 
            'SELECT '.
                'id,'.
                'start_date,'.
                'end_date,'.
                'schedule,'.
                'comment '.
            'FROM '.
                DB_PREFIX.'cal_schedule '.
            'WHERE '.
                'ref_account = '.$this->account['id'].' AND '.
                "start_date <= '".$this->limitday['last']."' AND ".
                "end_date >= '".$this->limitday['start']."' ".
            'ORDER BY '.
                'start_date';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);

        if (empty($result)){
            return ;
        }

        $list = array();
        $schedule = array();
        foreach ($result as $value){
            $this->set_schedules($value);
        }
        $this->Assign('schedule', $result);
        $this->Assign('schedules', $this->schedules);
    }

    /**
     * カレンダー用アイテムの設定
     *
     * @access private
     * @param integer $ref_item
     * @return array
     */
    function set_schedules($values)
    {
        $calendar = mb_strimwidth($values['schedule'], 0, 12, '');

        $start = explode('-',$values['start_date']);
        $end  = explode('-',$values['end_date']);

        $dates  = $this->objcal->getDates();
        $last  = $this->objcal->getLastday();

        $offset = intval($start[RKT_DAY]);
        if ($start[RKT_MONTH] != $dates[RKT_MONTH]){
            $offset = 1;
        }

        $limit = intval($end[RKT_DAY]);
        if ($end[RKT_MONTH] != $dates[RKT_MONTH]){
            $limit = $last;
        }

        for ($day=$offset; $day<=$limit; $day++){
            $this->schedules[$day][] = array(
                'id'=> $values['id'],
                'calendar'=> $calendar
            );
        }
    }

    /**
     * 誕生日リストの設定
     *
     * @access private
     * @return void
     **/
    function set_birthday($flag=0)
    {
        $relation = array(
            'ref_friend',
            'ref_account',
        );
        $reference = array(
            'ref_account',
            'ref_friend',
        );

        $date_format  = sql_query::dateFormat('pro.birthday','%d'); 
        $month_format = sql_query::dateFormat('pro.birthday','%m'); 
        $sql=
            'SELECT '.
                'act.id as id,'.
                'pro.nickname as nickname,'.
                $date_format.' as day '.
            'FROM '.
                DB_PREFIX.'act_account act,'.
                DB_PREFIX.'act_profile pro,'.
                DB_PREFIX.'fri_friends fri '.
            'WHERE '.
                'act.id = pro.ref_account AND '.
                'act.id = fri.'.$relation[$flag].' AND '.
                'act.avail = '.AVAIL_ENABLE.' AND '.
                'fri.avail = '.AVAIL_ENABLE.' AND '.
                'fri.status = '.STATUS_FRIEND_CONNECT.' AND '.
                'fri.'.$reference[$flag].' = '.$this->account['id'] .' AND '.
                $month_format." = '".$this->limitday['month']."' ".
            'ORDER BY '.
                'pro.birthday';
        $stmt = $this->objdb->prepare($sql);
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
        if(empty($result)){
            return ;
        }

        foreach ($result as $value){
            $this->birthdays[intval($value['day'])][] = array(
                'id'=>   $value['id'],
                'nickname'=> $value['nickname']
            );
        }
    }

    /**
     * イベントリストの設定
     *
     * @access private
     * @return void
     **/
    function set_event()
    {
        $date_format  = sql_query::dateFormat('tpc.start_date','%d');
        $month_format = sql_query::dateFormat('tpc.start_date','%m'); 
        $sql=
            'SELECT '.
                'tpc.id as id,'.
                'tpc.ref_community as ref_community,'.
                'tpc.topic as topic,'.
                $date_format.' as day '.
            'FROM '.
                DB_PREFIX.'com_names nam,'.
                DB_PREFIX.'com_topic tpc '.
            'WHERE '.
                'nam.ref_community = tpc.ref_community AND '.
                'tpc.status = '.STATUS_TOPIC_EVENT.' AND '.
                'nam.ref_account = '.$this->account['id'].' AND '.
                '(nam.status = '.STATUS_COMMUNITY_ADMIN.' OR '.
                 'nam.status = '.STATUS_COMMUNITY_MEMBER.' OR '.
                 'nam.status = '.STATUS_COMMUNITY_CHANGE.') AND '.
                $month_format." = '".$this->limitday['month']."' ".
            'ORDER BY '.
                'tpc.start_date';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
        if(empty($result)){
            return ;
        }

        $list = array();
        foreach ($result as $value){
            $list[intval($value['day'])][] = array(
                'id'=>        $value['id'],
                'ref_community'=> $value['ref_community'],
                'topic'=>     $value['topic']
            );
        }
        $this->Assign('events', $list);
    }
} // webapp
?>

==> rktSNS_1.070528.tgz: rktSNS/webapp/modules/private/show/calendar.php <==
<?php
/* ========================================================================
 - [modules/private/show/calendar.php]
 -      カレンダー
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2007/02/13] 誕生日が重複するエラーを修正
 -      [2007/02/12] コミュニティメンバーステータスをビットフラグに変更
 -      [2006/07/10] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once LIB_DIR.'rkt_pager.php';
require_once LIB_DIR.'rkt_calendar.php';
require_once WEBAPP_LIB_DIR.'sql_query.php';
require_once WEBAPP_LIB_DIR.'wap_private.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends WAP_private
{
    /**
     * 表示対象年月日
     * @var string
     */
    var $date = '';

    /**
     * カレンダーオブジェクト
     * @var object
     */
    var $objcal = null;

    /**
     * スケジュール格納用
     * @var array
     */
    var $schedules = array();

    /**
     * 誕生日格納用
     * @var array
     */
    var $birthdays = array();

    /**
     * イベント格納用
     * @var array
     */
    var $events = array();

    /**
     * 日付の参照範囲
     * @var array
     */
    var $limitday = array();

    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    function execute()
    {
        RKT_auth::Authenticate(array(WAP_ACC_ADMIN,WAP_ACC_MEMBER));

        $this->setTemplateFile('private/show/calendar.tpl');

        /* 表示対象日付 */
        $this->setSafety('date', '_REQUEST', 'string');

        /* カレンダーオブジェクトの生成 */
        $this->objcal = new RKT_calendar($this->date);
        
        $this->set_calendar();
        $this->set_schedule();
        $this->set_birthday();
        $this->Assign('birthdays', $this->birthdays);
        
        $this->set_event();
    }

    /**
     * カレンダーの設定
     *
     * @access private
     */
    function set_calendar()
    {
        $id2yobi = array(    // idから曜日に変換
            RKT_SUN => 'sun',
            RKT_MON => 'mon',
            RKT_TUE => 'tue',
            RKT_WED => 'wed',
            RKT_THU => 'thu',
            RKT_FRI => 'fri',
            RKT_SAT => 'sat'
        );

        $id2style = array(    // idからcssクラス名に変換
            RKT_WEEKDAY => 'calendar',
            RKT_HOLIDAY => 'holiday',
            RKT_SATURDAY =>'saturday',
            RKT_TODAY =>   'today'
        );
        $cals   = $this->objcal->getCalendar();
        $infos  = $this->objcal->getInformation();
        $dates  = $this->objcal->getDates();
        $last   = $this->objcal->getLastday();

        $weeks = array();
        $yobi = '';
        $style = '';

        $calendars = array();
        foreach ($cals as $weekly=>$weeks){
            $cal[$weekly] = array();
            foreach ($weeks as $week=>$day){
                $style = $id2style[$infos[$weekly][$week]];
                if (!empty($this->weeks[$weekly][$week]) && !empty($day)){
                    $this->schedule[$day] = $this->weeks[$weekly][$week];
                }
        
                $calendars[$weekly]['week'][$week] = array('day'=>$day,'style'=>$style);                
            }
        } // foreach ($cals as $weekly=>$weeks)
        $this->month = sprintf('%04d-%02d',$dates[RKT_YEAR],$dates[RKT_MONTH]);

        $this->limitday['start'] =  sprintf('%04d-%02d-01',$dates[RKT_YEAR],$dates[RKT_MONTH]);
        $this->limitday['last']  =  sprintf('%04d-%02d-%d',$dates[RKT_YEAR],$dates[RKT_MONTH],$last);
        $this->limitday['month'] =  sprintf('%02d',$dates[RKT_MONTH]);

        $this->Assign('calendars', $calendars);
        $this->Assign('date', $dates);
        $this->Assign('month', $dates[RKT_MONTH]);
    }

    /**
     * スケジュールリストの設定
     *
     * @access private
     * @return void
     **/
    function set_schedule()
    {
        $sql = 
            'SELECT '.
                'id,'.
                'start_date,'.
                'end_date,'.
                'schedule,'.
                'comment '.
            'FROM '.
                DB_PREFIX.'cal_schedule '.
            'WHERE '.
                'ref_account = '.$this->account['id'].' AND '.
                "start_date <= '".$this->limitday['last']."' AND ".
                "end_date >= '".$this->limitday['start']."' ".
            'ORDER BY '.
                'start_date';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);

        if (empty($result)){
            return ;
        }

        $list = array();
        $schedule = array();
        foreach ($result as $value){
            $this->set_schedules($value);
        }
        $this->Assign('schedule', $result);
        $this->Assign('schedules', $this->schedules);
    }

    /**
     * カレンダー用アイテムの設定
     *
     * @access private
     * @param integer $ref_item
     * @return array
     */
    function set_schedules($values)
    {
        $calendar = mb_strimwidth($values['schedule'], 0, 12, '');

        $start = explode('-',$values['start_date']);
        $end  = explode('-',$values['end_date']);

        $dates  = $this->objcal->getDates();
        $last  = $this->objcal->getLastday();

        $offset = intval($start[RKT_DAY]);
        if ($start[RKT_MONTH] != $dates[RKT_MONTH]){
            $offset = 1;
        }

        $limit = intval($end[RKT_DAY]);
        if ($end[RKT_MONTH] != $dates[RKT_MONTH]){
            $limit = $last;
        }

        for ($day=$offset; $day<=$limit; $day++){
            $this->schedules[$day][] = array(
                'id'=> $values['id'],
                'calendar'=> $calendar
            );
        }
    }

    /**
     * 誕生日リストの設定
     *
     * @access private
     * @return void
     **/
    function set_birthday()
    {
        $date_format  = sql_query::dateFormat('pro.birthday','%d'); 
        $month_format = sql_query::dateFormat('pro.birthday','%m'); 
        $sql=
            'SELECT '.
                'act.id as id,'.
                'pro.nickname as nickname,'.
                $date_format.' as day '.
            'FROM '.
                DB_PREFIX.'act_account act,'.
                DB_PREFIX.'act_profile pro,'.
                DB_PREFIX.'fri_friends fri '.
            'WHERE '.
                'act.id = pro.ref_account AND '.
                'act.id = fri.ref_friend AND '.
                'act.avail = '.AVAIL_ENABLE.' AND '.
                'fri.avail = '.AVAIL_ENABLE.' AND '.
                'fri.status = '.STATUS_FRIEND_CONNECT.' AND '.
                'fri.ref_account = '.$this->account['id'] .' AND '.
                $month_format." = '".$this->limitday['month']."' ".
            'ORDER BY '.
                'pro.birthday';
        $stmt = $this->objdb->prepare($sql);
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
        if(empty($result)){
            return ;
        }

        foreach ($result as $value){
            $this->birthdays[intval($value['day'])][] = array(
                'id'=>   $value['id'],
                'nickname'=> $value['nickname']
            );
        }
    }

    /**
     * イベントリストの設定
     *
     * @access private
     * @return void
     **/
    function set_event()
    {
        $date_format  = sql_query::dateFormat('tpc.start_date','%d');
        $month_format = sql_query::dateFormat('tpc.start_date','%m'); 
        $sql=
            'SELECT '.
                'tpc.id as id,'.
                'tpc.ref_community as ref_community,'.
                'tpc.topic as topic,'.
                $date_format.' as day '.
            'FROM '.
                DB_PREFIX.'com_names nam,'.
                DB_PREFIX.'com_topic tpc '.
            'WHERE '.
                'nam.ref_community = tpc.ref_community AND '.
                'tpc.status = '.STATUS_TOPIC_EVENT.' AND '.
                'nam.ref_account = '.$this->account['id'].' AND '.
                sql_query::bitFlag('nam.status & '.STATUS_COMMUNITY_MEMBERS).' AND '.
                $month_format." = '".$this->limitday['month']."' ".
            'ORDER BY '.
                'tpc.start_date';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
        if(empty($result)){
            return ;
        }

        $list = array();
        foreach ($result as $value){
            $list[intval($value['day'])][] = array(
                'id'=>        $value['id'],
                'ref_community'=> $value['ref_community'],
                'topic'=>     $value['topic']
            );
        }
        $this->Assign('events', $list);
    }
} // webapp
?>
